@@ -4,6 +4,21 @@ from http import HTTPStatus
 from pydantic import BaseModel, Field
 
 
+class MessageText(str):
+    def contains(self, text: str, case_sens=False) -> bool:
+        if not case_sens:
+            result = text.lower() in self.lower()
+        else:
+            result = text in self
+        return result
+
+    def contains_any(self, texts: list, case_sens=False) -> bool:
+        for text in texts:
+            if self.contains(text, case_sens):
+                return True
+        return False
+
+
 class Client(BaseModel):
     name: str = Field(...)
 
@@ -16,10 +31,14 @@ class User(BaseModel):
 
 class Message(BaseModel):
     user: User = Field(...)
-    text: str = Field(...)
+    text: MessageText = Field(...)
     binaries: typing.Optional[str] = Field(None)
     timestamp: typing.Union[float, int] = Field(default=datetime.now().timestamp())
 
+    def __init__(self, *args, **kwargs):
+        kwargs['text'] = MessageText(kwargs['text'])
+        super().__init__(*args, **kwargs)
+
 
 class SkillResponse(BaseModel):
     """ Response Model for testsuite
